@@ -338,6 +338,31 @@ static int unwind_exec_pop_subset_r0_to_r3(struct unwind_ctrl_s *ctrl,
   return 0;
 }
 
+static unsigned long unwind_decode_uleb128(struct unwind_ctrl_s *ctrl)
+{
+  unsigned long bytes = 0;
+  unsigned long insn;
+  unsigned long result = 0;
+
+  /* unwind_get_byte() will advance `ctrl` one instruction at a time, so
+   * loop until we get an instruction byte where bit 7 is not set.
+   *
+   * Note: This decodes a maximum of 4 bytes to output 28 bits data where
+   * max is 0xfffffff: that will cover a vsp increment of 1073742336, hence
+   * it is sufficient for unwinding the stack.
+   */
+
+  do
+    {
+      insn = unwind_get_byte(ctrl);
+      result |= (insn & 0x7f) << (bytes * 7);
+      bytes++;
+    }
+  while (!!(insn & 0x80) && (bytes != sizeof(result)));
+
+  return result;
+}
+
 /****************************************************************************
  * Name: unwind_pop_register
  *
@@ -403,10 +428,66 @@ static int unwind_exec_content(struct unwind_ctrl_s *ctrl)
     }
   else if (content == 0xb2)
     {
-      unsigned long uleb128 = unwind_get_byte(ctrl);
+      unsigned long uleb128 = unwind_decode_uleb128(ctrl);
 
       ctrl->vrs[SP] += 0x204 + (uleb128 << 2);
     }
+  else if (content == 0xb3 || content == 0xc8 || content == 0xc9)
+    {
+      unsigned long reg_from;
+      unsigned long reg_to;
+      unsigned long mask;
+      unsigned long *vsp = (unsigned long *)ctrl->vrs[SP];
+      int i;
+
+      mask = unwind_get_byte(ctrl);
+      if (mask == 0)
+        {
+          return -1;
+        }
+
+      reg_from = (mask & 0xf0) >> 4;
+      reg_to = reg_from + (mask & 0x0f);
+
+      if (content == 0xc8)
+        {
+          reg_from += 16;
+          reg_to += 16;
+        }
+
+      for (i = reg_from; i <= reg_to; i++)
+        {
+          vsp += 2;
+        }
+
+      if (content == 0xb3)
+        {
+          vsp++;
+        }
+
+      ctrl->vrs[SP] = (unsigned long)vsp;
+    }
+  else if ((content & 0xf8) == 0xb8 || (content & 0xf8) == 0xd0)
+    {
+      unsigned long reg_to;
+      unsigned long mask = content & 0x07;
+      unsigned long *vsp = (unsigned long *)ctrl->vrs[SP];
+      int i;
+
+      reg_to = 8 + mask;
+
+      for (i = 8; i <= reg_to; i++)
+        {
+          vsp += 2;
+        }
+
+      if ((content & 0xf8) == 0xb8)
+        {
+          vsp++;
+        }
+
+      ctrl->vrs[SP] = (unsigned long)vsp;
+    }
   else
     {
       ret = -1;
@@ -431,6 +512,7 @@ int unwind_frame(struct unwind_frame_s *frame)
   ctrl.vrs[LR] = frame->lr;
   ctrl.vrs[PC] = 0;
   ctrl.stack_top = frame->stack_top;
+  ctrl.lr_addr = NULL;
 
   if (frame->pc == prel31_to_addr(&entry->fnoffset))
     {
