@@ -553,7 +553,7 @@ int cxd56_rtc_setalarm(struct alm_setalarm_s *alminfo)
   id = alminfo->as_id;
   cbinfo = &g_alarmcb[id];
 
-  if (cbinfo->ac_cb == NULL)
+  if (g_rtc_enabled && (cbinfo->ac_cb == NULL))
     {
       /* The set the alarm */
 
