@@ -31,7 +31,9 @@
  * families
  */
 
-#if defined(CONFIG_STM32H7_STM32H7X3XX) || defined(CONFIG_STM32H7_STM32H7B3XX)
+#if defined(CONFIG_STM32H7_STM32H7X3XX) || \
+    defined(CONFIG_STM32H7_STM32H7B3XX) || \
+    defined(CONFIG_STM32H7_STM32H7X5XX)
 
 /****************************************************************************
  * Pre-processor Definitions
