@@ -99,7 +99,6 @@ struct stm32_rptun_dev_s
   bool                        master;
   struct stm32_rptun_shmem_s *shmem;
   char                        cpuname[RPMSG_NAME_SIZE + 1];
-  char                        shmemname[RPMSG_NAME_SIZE + 1];
 };
 
 /****************************************************************************
@@ -107,9 +106,6 @@ struct stm32_rptun_dev_s
  ****************************************************************************/
 
 static const char *stm32_rptun_get_cpuname(struct rptun_dev_s *dev);
-static const char *stm32_rptun_get_firmware(struct rptun_dev_s *dev);
-static const struct rptun_addrenv_s *
-stm32_rptun_get_addrenv(struct rptun_dev_s *dev);
 static struct rptun_rsc_s *
 stm32_rptun_get_resource(struct rptun_dev_s *dev);
 static bool stm32_rptun_is_autostart(struct rptun_dev_s *dev);
@@ -133,8 +129,6 @@ static void stm32_rptun_panic(struct rptun_dev_s *dev);
 static const struct rptun_ops_s g_stm32_rptun_ops =
 {
   .get_cpuname       = stm32_rptun_get_cpuname,
-  .get_firmware      = stm32_rptun_get_firmware,
-  .get_addrenv       = stm32_rptun_get_addrenv,
   .get_resource      = stm32_rptun_get_resource,
   .is_autostart      = stm32_rptun_is_autostart,
   .is_master         = stm32_rptun_is_master,
@@ -173,25 +167,6 @@ static const char *stm32_rptun_get_cpuname(struct rptun_dev_s *dev)
   return priv->cpuname;
 }
 
-/****************************************************************************
- * Name: stm32_rptun_get_firmware
- ****************************************************************************/
-
-static const char *stm32_rptun_get_firmware(struct rptun_dev_s *dev)
-{
-  return NULL;
-}
-
-/****************************************************************************
- * Name: stm32_rptun_get_addrenv
- ****************************************************************************/
-
-static const struct rptun_addrenv_s *
-stm32_rptun_get_addrenv(struct rptun_dev_s *dev)
-{
-  return NULL;
-}
-
 /****************************************************************************
  * Name: stm32_rptun_get_resource
  ****************************************************************************/
@@ -476,7 +451,7 @@ static int stm32_rptun_thread(int argc, char *argv[])
  * Public Functions
  ****************************************************************************/
 
-int stm32_rptun_init(const char *shmemname, const char *cpuname)
+int stm32_rptun_init(const char *cpuname)
 {
   struct stm32_rptun_dev_s *dev = &g_rptun_dev;
   int                       ret = OK;
@@ -506,7 +481,6 @@ int stm32_rptun_init(const char *shmemname, const char *cpuname)
 
   dev->rptun.ops = &g_stm32_rptun_ops;
   strncpy(dev->cpuname, cpuname, RPMSG_NAME_SIZE);
-  strncpy(dev->shmemname, shmemname, RPMSG_NAME_SIZE);
 
   ret = rptun_initialize(&dev->rptun);
   if (ret < 0)
@@ -527,43 +501,3 @@ int stm32_rptun_init(const char *shmemname, const char *cpuname)
 errout:
   return ret;
 }
-
-/****************************************************************************
- * Name: up_addrenv_va_to_pa
- *
- * Description:
- *   This is needed by openamp/libmetal/lib/system/nuttx/io.c:78. The
- *   physical memory is mapped as virtual.
- *
- * Input Parameters:
- *   va_
- *
- * Returned Value:
- *   va
- *
- ****************************************************************************/
-
-uintptr_t up_addrenv_va_to_pa(void *va)
-{
-  return (uintptr_t)va;
-}
-
-/****************************************************************************
- * Name: up_addrenv_pa_to_va
- *
- * Description:
- *   This is needed by openamp/libmetal/lib/system/nuttx/io.c. The
- *   physical memory is mapped as virtual.
- *
- * Input Parameters:
- *   pa
- *
- * Returned Value:
- *   pa
- *
- ****************************************************************************/
-
-void *up_addrenv_pa_to_va(uintptr_t pa)
-{
-  return (void *)pa;
-}
