@@ -141,12 +141,6 @@ static const struct rtc_ops_s g_rtc_ops =
   .setperiodic    = stm32wb_setperiodic,
   .cancelperiodic = stm32wb_cancelperiodic,
 #endif
-#ifdef CONFIG_RTC_IOCTL
-  .ioctl       = NULL,
-#endif
-#ifndef CONFIG_DISABLE_PSEUDOFS_OPERATIONS
-  .destroy     = NULL,
-#endif
 };
 
 /* STM32WB RTC device state */
