@@ -32,6 +32,7 @@
  */
 #ifndef __ASSEMBLY__
   #include <stdint.h>
+  #include <nuttx/nuttx.h>
 #endif
 
 #include <sys/param.h>
@@ -143,8 +144,6 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-#define STRINGIFY(x)    #x
-
 #define GET_EL(mode)  (((mode) >> MODE_EL_SHIFT) & MODE_EL_MASK)
 
 /* MPIDR_EL1, Multiprocessor Affinity Register */
