@@ -34,6 +34,7 @@
 #include <sys/types.h>
 #include <time.h>
 
+#include <nuttx/nuttx.h>
 #include <nuttx/arch.h>
 #include <nuttx/irq.h>
 #include <nuttx/kthread.h>
@@ -80,7 +81,6 @@
 /* rptun initialization names */
 
 #define MPFS_RPTUN_CPU_NAME      "mpfs-ihc"
-#define MPFS_RPTUN_SHMEM_NAME    "mpfs-shmem"
 
 /* Vring configuration parameters */
 
@@ -114,8 +114,6 @@
 struct mpfs_rptun_shmem_s
 {
   volatile uintptr_t         base;
-  volatile unsigned int      seqs;
-  volatile unsigned int      seqm;
   struct rptun_rsc_s         rsc;
   bool                       master_up;
 };
@@ -127,11 +125,9 @@ struct mpfs_rptun_dev_s
   rptun_callback_t           callback;
   void                      *arg;
   bool                       master;
-  unsigned int               seq;
   struct mpfs_rptun_shmem_s *shmem;
   struct simple_addrenv_s    addrenv[VRINGS];
   char                       cpuname[RPMSG_NAME_SIZE + 1];
-  char                       shmemname[RPMSG_NAME_SIZE + 1];
 };
 
 struct mpfs_queue_table_s
@@ -150,9 +146,6 @@ struct mpfs_ihc_work_arg_s
  ****************************************************************************/
 
 static const char *mpfs_rptun_get_cpuname(struct rptun_dev_s *dev);
-static const char *mpfs_rptun_get_firmware(struct rptun_dev_s *dev);
-static const struct rptun_addrenv_s
-*mpfs_rptun_get_addrenv(struct rptun_dev_s *dev);
 static struct rptun_rsc_s *mpfs_rptun_get_resource(struct rptun_dev_s *dev);
 static bool mpfs_rptun_is_autostart(struct rptun_dev_s *dev);
 static bool mpfs_rptun_is_master(struct rptun_dev_s *dev);
@@ -226,8 +219,6 @@ const uint32_t ihcia_remote_hart_ints[MPFS_NUM_HARTS] =
 static const struct rptun_ops_s g_mpfs_rptun_ops =
 {
   .get_cpuname       = mpfs_rptun_get_cpuname,
-  .get_firmware      = mpfs_rptun_get_firmware,
-  .get_addrenv       = mpfs_rptun_get_addrenv,
   .get_resource      = mpfs_rptun_get_resource,
   .is_autostart      = mpfs_rptun_is_autostart,
   .is_master         = mpfs_rptun_is_master,
@@ -839,45 +830,6 @@ static const char *mpfs_rptun_get_cpuname(struct rptun_dev_s *dev)
   return priv->cpuname;
 }
 
-/****************************************************************************
- * Name: mpfs_rptun_get_firmware
- *
- * Description:
- *   Gets the mpfs rptun firmware.
- *
- * Input Parameters:
- *   dev   - Rptun device.
- *
- * Returned Value:
- *   Always null, no associated firmware present
- *
- ****************************************************************************/
-
-static const char *mpfs_rptun_get_firmware(struct rptun_dev_s *dev)
-{
-  return NULL;
-}
-
-/****************************************************************************
- * Name: mpfs_rptun_get_addrenv
- *
- * Description:
- *   Gets the mpfs rptun addrenv.
- *
- * Input Parameters:
- *   dev   - Rptun device.
- *
- * Returned Value:
- *   Always null, no associated addrenv present.
- *
- ****************************************************************************/
-
-static const struct rptun_addrenv_s *
-mpfs_rptun_get_addrenv(struct rptun_dev_s *dev)
-{
-  return NULL;
-}
-
 /****************************************************************************
  * Name: mpfs_rptun_get_resource
  *
@@ -914,8 +866,6 @@ mpfs_rptun_get_resource(struct rptun_dev_s *dev)
       rsc = &priv->shmem->rsc;
 
       g_shmem.base = VRING_SHMEM;
-      g_shmem.seqm = 0;
-      g_shmem.seqs = 0;
 
       rsc->rsc_tbl_hdr.ver          = 1;
       rsc->rsc_tbl_hdr.num          = 1;
@@ -1129,7 +1079,6 @@ static int mpfs_rptun_register_callback(struct rptun_dev_s *dev,
  *   Initializes the rptun device.
  *
  * Input Parameters:
- *   shmemname  - Shared mempory name
  *   cpuname    - Local CPU name
  *
  * Returned Value:
@@ -1137,7 +1086,7 @@ static int mpfs_rptun_register_callback(struct rptun_dev_s *dev,
  *
  ****************************************************************************/
 
-static int mpfs_rptun_init(const char *shmemname, const char *cpuname)
+static int mpfs_rptun_init(const char *cpuname)
 {
   struct mpfs_rptun_dev_s *dev;
   int ret;
@@ -1156,7 +1105,6 @@ static int mpfs_rptun_init(const char *shmemname, const char *cpuname)
 
   dev->rptun.ops = &g_mpfs_rptun_ops;
   strlcpy(dev->cpuname, cpuname, sizeof(dev->cpuname));
-  strlcpy(dev->shmemname, shmemname, sizeof(dev->shmemname));
   list_add_tail(&g_dev_list, &dev->node);
 
   ret = rptun_initialize(&dev->rptun);
@@ -1421,7 +1369,7 @@ int mpfs_ihc_init(void)
       g_shmem.rsc.rpmsg_vdev.status |= VIRTIO_CONFIG_STATUS_DRIVER_OK;
     }
 
-  ret = mpfs_rptun_init(MPFS_RPTUN_SHMEM_NAME, MPFS_RPTUN_CPU_NAME);
+  ret = mpfs_rptun_init(MPFS_RPTUN_CPU_NAME);
   if (ret < 0)
     {
       ihcerr("ERROR: Not able to init RPTUN\n");
@@ -1467,43 +1415,3 @@ init_error:
   up_disable_irq(g_plic_irq);
   return ret;
 }
-
-/****************************************************************************
- * Name: up_addrenv_va_to_pa
- *
- * Description:
- *   This is needed by openamp/libmetal/lib/system/nuttx/io.c:78. The
- *   physical memory is mapped as virtual.
- *
- * Input Parameters:
- *   va_
- *
- * Returned Value:
- *   va
- *
- ****************************************************************************/
-
-uintptr_t up_addrenv_va_to_pa(void *va)
-{
-  return (uintptr_t)va;
-}
-
-/****************************************************************************
- * Name: up_addrenv_pa_to_va
- *
- * Description:
- *   This is needed by openamp/libmetal/lib/system/nuttx/io.c. The
- *   physical memory is mapped as virtual.
- *
- * Input Parameters:
- *   pa
- *
- * Returned Value:
- *   pa
- *
- ****************************************************************************/
-
-void *up_addrenv_pa_to_va(uintptr_t pa)
-{
-  return (void *)pa;
-}
