@@ -86,12 +86,6 @@ static uint64_t *common_handler(int irq, uint64_t *regs)
 
   if (regs != g_current_regs)
     {
-#ifdef CONFIG_ARCH_FPU
-      /* Restore floating point registers */
-
-      up_restorefpu((uint64_t *)g_current_regs);
-#endif
-
 #ifdef CONFIG_ARCH_ADDRENV
       /* Make sure that the address environment for the previously
        * running task is closed down gracefully (data caches dump,
