@@ -90,6 +90,14 @@ struct esp32s2_uart_s g_uart0_config =
   .oflow          = false,   /* output flow control (CTS) disabled */
 #endif
 #endif
+#ifdef CONFIG_ESP32S2_UART0_RS485
+  .rs485_dir_gpio = CONFIG_ESP32S2_UART0_RS485_DIR_PIN,
+#if (CONFIG_ESP32S2_UART0_RS485_DIR_POLARITY == 0)
+  .rs485_dir_polarity = false,
+#else
+  .rs485_dir_polarity = true,
+#endif
+#endif
 };
 
 #endif /* CONFIG_ESP32S2_UART0 */
@@ -129,6 +137,14 @@ struct esp32s2_uart_s g_uart1_config =
   .oflow          = false,   /* output flow control (CTS) disabled */
 #endif
 #endif
+#ifdef CONFIG_ESP32S2_UART1_RS485
+  .rs485_dir_gpio = CONFIG_ESP32S2_UART1_RS485_DIR_PIN,
+#if (CONFIG_ESP32S2_UART1_RS485_DIR_POLARITY == 0)
+  .rs485_dir_polarity = false,
+#else
+  .rs485_dir_polarity = true,
+#endif
+#endif
 };
 
 #endif /* CONFIG_ESP32S2_UART1 */
@@ -501,6 +517,25 @@ void esp32s2_lowputc_stop_length(const struct esp32s2_uart_s *priv)
     }
 }
 
+/****************************************************************************
+ * Name: esp32s2_lowputc_set_tx_idle_time
+ *
+ * Description:
+ *   Set the idle time between transfers.
+ *
+ * Parameters:
+ *   priv           - Pointer to the private driver struct.
+ *   time           - Desired time interval between the transfers.
+ *
+ ****************************************************************************/
+
+void esp32s2_lowputc_set_tx_idle_time(const struct esp32s2_uart_s *priv,
+                                      uint32_t time)
+{
+  modifyreg32(UART_IDLE_CONF_REG(priv->id), UART_TX_IDLE_NUM_M,
+              VALUE_TO_FIELD(time, UART_TX_IDLE_NUM));
+}
+
 /****************************************************************************
  * Name: esp32s2_lowputc_send_byte
  *
@@ -716,6 +751,15 @@ void esp32s2_lowputc_config_pins(const struct esp32s2_uart_s *priv)
       esp32s2_gpio_matrix_in(priv->ctspin, priv->ctssig, 0);
     }
 #endif
+
+#ifdef HAVE_RS485
+  if (priv->rs485_dir_gpio != 0)
+    {
+      esp32s2_configgpio(priv->rs485_dir_gpio, OUTPUT);
+      esp32s2_gpio_matrix_out(priv->rs485_dir_gpio, SIG_GPIO_OUT_IDX, 0, 0);
+      esp32s2_gpiowrite(priv->rs485_dir_gpio, !priv->rs485_dir_polarity);
+    }
+#endif
 }
 
 /****************************************************************************
