@@ -895,7 +895,8 @@ static IRAM_ATTR int i2s_txdma_setup(struct esp32s3_i2s_s *priv,
 
   bytes_queued = esp32s3_dma_setup(outlink, I2S_DMADESC_NUM,
                                    bfcontainer->buf,
-                                   bfcontainer->nbytes, I2S_TX);
+                                   bfcontainer->nbytes, I2S_TX,
+                                   priv->dma_channel);
 
   if (bytes_queued != bfcontainer->nbytes)
     {
@@ -956,7 +957,8 @@ static int i2s_rxdma_setup(struct esp32s3_i2s_s *priv,
 
   bytes_queued = esp32s3_dma_setup(inlink, I2S_DMADESC_NUM,
                                    bfcontainer->apb->samp,
-                                   bfcontainer->nbytes, I2S_RX);
+                                   bfcontainer->nbytes, I2S_RX,
+                                   priv->dma_channel);
 
   if (bytes_queued != bfcontainer->nbytes)
     {
@@ -2772,12 +2774,12 @@ static int i2s_send(struct i2s_dev_s *dev, struct ap_buffer_s *apb,
 
       nbytes -= (nbytes % (priv->data_width / 8));
 
-      if (nbytes > (ESP32S3_DMA_DATALEN_MAX * I2S_DMADESC_NUM))
+      if (nbytes > (ESP32S3_DMA_BUFLEN_MAX * I2S_DMADESC_NUM))
         {
           i2serr("Required buffer size can't fit into DMA outlink "
                  "(exceeds in %" PRIu32 " bytes). Try to increase the "
                  "number of the DMA descriptors (CONFIG_I2S_DMADESC_NUM).",
-                 nbytes - (ESP32S3_DMA_DATALEN_MAX * I2S_DMADESC_NUM));
+                 nbytes - (ESP32S3_DMA_BUFLEN_MAX * I2S_DMADESC_NUM));
           return -EFBIG;
         }
 
@@ -2880,7 +2882,7 @@ static int i2s_receive(struct i2s_dev_s *dev, struct ap_buffer_s *apb,
 
       nbytes -= (nbytes % (priv->data_width / 8));
 
-      nbytes = MIN(nbytes, ESP32S3_DMA_DATALEN_MAX);
+      nbytes = MIN(nbytes, ESP32S3_DMA_BUFLEN_MAX);
 
       /* Allocate a buffer container in advance */
 
