@@ -50,6 +50,7 @@
 
 #ifdef CONFIG_ESP32S3_SPI_DMA
 #include "esp32s3_dma.h"
+#include "hardware/esp32s3_dma.h"
 #endif
 
 #include "xtensa.h"
@@ -136,6 +137,7 @@ struct esp32s3_spi_config_s
 #ifdef CONFIG_ESP32S3_SPI_DMA
   uint32_t dma_clk_bit;       /* DMA clock enable bit */
   uint32_t dma_rst_bit;       /* DMA reset bit */
+  uint8_t dma_periph;         /* DMA peripheral */
 #endif
   uint32_t cs_insig;          /* SPI CS input signal index */
   uint32_t cs_outsig;         /* SPI CS output signal index */
@@ -204,12 +206,11 @@ static void esp32s3_spi_dma_exchange(struct esp32s3_spi_priv_s *priv,
                                      const void *txbuffer,
                                      void *rxbuffer,
                                      uint32_t nwords);
-#else
+#endif
 static void esp32s3_spi_poll_exchange(struct esp32s3_spi_priv_s *priv,
                                       const void *txbuffer,
                                       void *rxbuffer,
                                       size_t nwords);
-#endif
 #ifndef CONFIG_SPI_EXCHANGE
 static void esp32s3_spi_sndblock(struct spi_dev_s *dev,
                                  const void *txbuffer,
@@ -222,9 +223,9 @@ static void esp32s3_spi_recvblock(struct spi_dev_s *dev,
 static int esp32s3_spi_trigger(struct spi_dev_s *dev);
 #endif
 #ifdef CONFIG_ESP32S3_SPI_DMA
-static void esp32s3_spi_dma_init(struct spi_dev_s *dev);
+static int esp32s3_spi_dma_init(struct spi_dev_s *dev);
 #endif
-static void esp32s3_spi_init(struct spi_dev_s *dev);
+static int esp32s3_spi_init(struct spi_dev_s *dev);
 static void esp32s3_spi_deinit(struct spi_dev_s *dev);
 
 /****************************************************************************
@@ -251,6 +252,7 @@ static const struct esp32s3_spi_config_s esp32s3_spi2_config =
 #ifdef CONFIG_ESP32S3_SPI_DMA
   .dma_clk_bit  = SYSTEM_SPI2_DMA_CLK_EN,
   .dma_rst_bit  = SYSTEM_SPI2_DMA_RST,
+  .dma_periph   = ESP32S3_DMA_PERIPH_SPI2,
 #endif
   .cs_insig     = FSPICS0_IN_IDX,
   .cs_outsig    = FSPICS0_OUT_IDX,
@@ -345,15 +347,16 @@ static const struct esp32s3_spi_config_s esp32s3_spi3_config =
 #ifdef CONFIG_ESP32S3_SPI_DMA
   .dma_clk_bit  = SYSTEM_SPI3_DMA_CLK_EN,
   .dma_rst_bit  = SYSTEM_SPI3_DMA_RST,
+  .dma_periph   = ESP32S3_DMA_PERIPH_SPI3,
 #endif
-  .cs_insig     = FSPICS0_IN_IDX,
-  .cs_outsig    = FSPICS0_OUT_IDX,
-  .mosi_insig   = FSPID_IN_IDX,
-  .mosi_outsig  = FSPID_OUT_IDX,
-  .miso_insig   = FSPIQ_IN_IDX,
-  .miso_outsig  = FSPIQ_OUT_IDX,
-  .clk_insig    = FSPICLK_IN_IDX,
-  .clk_outsig   = FSPICLK_OUT_IDX
+  .cs_insig     = SPI3_CS0_IN_IDX,
+  .cs_outsig    = SPI3_CS0_OUT_IDX,
+  .mosi_insig   = SPI3_D_IN_IDX,
+  .mosi_outsig  = SPI3_D_OUT_IDX,
+  .miso_insig   = SPI3_Q_IN_IDX,
+  .miso_outsig  = SPI3_Q_OUT_IDX,
+  .clk_insig    = SPI3_CLK_IN_IDX,
+  .clk_outsig   = SPI3_CLK_OUT_IDX
 };
 
 static const struct spi_ops_s esp32s3_spi3_ops =
@@ -430,8 +433,8 @@ static struct esp32s3_spi_priv_s esp32s3_spi3_priv =
  *   Set the bits of the SPI register.
  *
  * Input Parameters:
- *   addr   - Address of the register of interest
- *   bits   - Bits to be set
+ *   addr - Address of the register of interest
+ *   bits - Bits to be set
  *
  * Returned Value:
  *   None.
@@ -452,8 +455,8 @@ static inline void esp32s3_spi_set_regbits(uint32_t addr, uint32_t bits)
  *   Clear the bits of the SPI register.
  *
  * Input Parameters:
- *   addr   - Address of the register of interest
- *   bits   - Bits to be cleared
+ *   addr - Address of the register of interest
+ *   bits - Bits to be cleared
  *
  * Returned Value:
  *   None.
@@ -511,8 +514,8 @@ static inline bool esp32s3_spi_iomux(struct esp32s3_spi_priv_s *priv)
  *   Lock or unlock the SPI device.
  *
  * Input Parameters:
- *   dev    - Device-specific state data
- *   lock   - true: Lock SPI bus, false: unlock SPI bus
+ *   dev  - Device-specific state data
+ *   lock - true: Lock SPI bus, false: unlock SPI bus
  *
  * Returned Value:
  *   The result of lock or unlock the SPI device.
@@ -894,10 +897,11 @@ static void esp32s3_spi_dma_exchange(struct esp32s3_spi_priv_s *priv,
     {
       /* Reset SPI DMA TX FIFO */
 
-      esp32s3_spi_set_regbits(SPI_DMA_CONF_REG(priv->config->id),
-                              SPI_DMA_RESET_MASK);
-      esp32s3_spi_clr_regbits(SPI_DMA_CONF_REG(priv->config->id),
-                              SPI_DMA_RESET_MASK);
+      SET_GDMA_CH_BITS(DMA_OUT_CONF0_CH0_REG, priv->dma_channel,
+                       DMA_OUT_RST_CH0);
+
+      CLR_GDMA_CH_BITS(DMA_OUT_CONF0_CH0_REG, priv->dma_channel,
+                       DMA_OUT_RST_CH0);
 
       /* Enable SPI DMA TX */
 
@@ -905,7 +909,7 @@ static void esp32s3_spi_dma_exchange(struct esp32s3_spi_priv_s *priv,
                               SPI_DMA_TX_ENA_M);
 
       n = esp32s3_dma_setup(priv->dma_txdesc, SPI_DMA_DESC_NUM,
-                            tp, bytes, true);
+                            tp, bytes, true, priv->dma_channel);
       esp32s3_dma_load(priv->dma_txdesc, channel, true);
       esp32s3_dma_enable(channel, true);
 
@@ -917,13 +921,21 @@ static void esp32s3_spi_dma_exchange(struct esp32s3_spi_priv_s *priv,
 
       if (rp != NULL)
         {
+          /* Reset SPI DMA RX FIFO */
+
+          SET_GDMA_CH_BITS(DMA_IN_CONF0_CH0_REG, priv->dma_channel,
+                           DMA_IN_RST_CH0);
+
+          CLR_GDMA_CH_BITS(DMA_IN_CONF0_CH0_REG, priv->dma_channel,
+                           DMA_IN_RST_CH0);
+
           /* Enable SPI DMA RX */
 
           esp32s3_spi_set_regbits(SPI_DMA_CONF_REG(priv->config->id),
                                   SPI_DMA_RX_ENA_M);
 
           esp32s3_dma_setup(priv->dma_rxdesc, SPI_DMA_DESC_NUM,
-                            rp, bytes, false);
+                            rp, bytes, false, priv->dma_channel);
           esp32s3_dma_load(priv->dma_rxdesc, channel, false);
           esp32s3_dma_enable(channel, false);
 
@@ -979,6 +991,14 @@ static void esp32s3_spi_dma_exchange(struct esp32s3_spi_priv_s *priv,
 static uint32_t esp32s3_spi_poll_send(struct esp32s3_spi_priv_s *priv,
                                       uint32_t wd)
 {
+#ifdef CONFIG_ESP32S3_SPI_DMA
+  esp32s3_spi_clr_regbits(SPI_DMA_CONF_REG(priv->config->id),
+                          SPI_DMA_TX_ENA_M);
+
+  esp32s3_spi_clr_regbits(SPI_DMA_CONF_REG(priv->config->id),
+                          SPI_DMA_RX_ENA_M);
+#endif
+
   uint32_t val;
 
   putreg32((priv->nbits - 1), SPI_MS_DLEN_REG(priv->config->id));
@@ -1059,6 +1079,14 @@ static void esp32s3_spi_poll_exchange(struct esp32s3_spi_priv_s *priv,
                                       void *rxbuffer,
                                       size_t nwords)
 {
+#ifdef CONFIG_ESP32S3_SPI_DMA
+  esp32s3_spi_clr_regbits(SPI_DMA_CONF_REG(priv->config->id),
+                          SPI_DMA_TX_ENA_M);
+
+  esp32s3_spi_clr_regbits(SPI_DMA_CONF_REG(priv->config->id),
+                          SPI_DMA_RX_ENA_M);
+#endif
+
   const uint32_t total_bytes = nwords * (priv->nbits / 8);
   uintptr_t bytes_remaining = total_bytes;
   const uint8_t *tp = (const uint8_t *)txbuffer;
@@ -1198,7 +1226,7 @@ static void esp32s3_spi_exchange(struct spi_dev_s *dev,
 #ifdef CONFIG_ESP32S3_SPI_DMA
   size_t thld = CONFIG_ESP32S3_SPI_DMATHRESHOLD;
 
-  if (nwords > thld)
+  if ((nwords * priv->nbits) / 8 > thld)
     {
       esp32s3_spi_dma_exchange(priv, txbuffer, rxbuffer, nwords);
     }
@@ -1277,7 +1305,7 @@ static void esp32s3_spi_recvblock(struct spi_dev_s *dev,
  *   Trigger a previously configured DMA transfer.
  *
  * Input Parameters:
- *   dev      - Device-specific state data
+ *   dev - Device-specific state data
  *
  * Returned Value:
  *   OK       - Trigger was fired
@@ -1293,6 +1321,8 @@ static int esp32s3_spi_trigger(struct spi_dev_s *dev)
 }
 #endif
 
+#ifdef CONFIG_ESP32S3_SPI_DMA
+
 /****************************************************************************
  * Name: esp32s3_spi_dma_init
  *
@@ -1300,15 +1330,14 @@ static int esp32s3_spi_trigger(struct spi_dev_s *dev)
  *   Initialize ESP32-S3 SPI connection to GDMA engine.
  *
  * Input Parameters:
- *   dev      - Device-specific state data
+ *   dev - Device-specific state data
  *
  * Returned Value:
- *   None.
+ *   OK on success; A negated errno value on failure.
  *
  ****************************************************************************/
 
-#ifdef CONFIG_ESP32S3_SPI_DMA
-void esp32s3_spi_dma_init(struct spi_dev_s *dev)
+static int esp32s3_spi_dma_init(struct spi_dev_s *dev)
 {
   struct esp32s3_spi_priv_s *priv = (struct esp32s3_spi_priv_s *)dev;
 
@@ -1326,19 +1355,53 @@ void esp32s3_spi_dma_init(struct spi_dev_s *dev)
 
   /* Request a GDMA channel for SPI peripheral */
 
-  priv->dma_channel = esp32s3_dma_request(ESP32S3_DMA_PERIPH_SPI2, 1, 1,
+  priv->dma_channel = esp32s3_dma_request(priv->config->dma_periph, 1, 1,
                                           true);
   if (priv->dma_channel < 0)
     {
       spierr("Failed to allocate GDMA channel\n");
 
-      DEBUGPANIC();
+      esp32s3_dma_deinit();
+      return ERROR;
     }
 
   /* Disable segment transaction mode for SPI Master */
 
   putreg32((SPI_SLV_RX_SEG_TRANS_CLR_EN_M | SPI_SLV_TX_SEG_TRANS_CLR_EN_M),
            SPI_DMA_CONF_REG(priv->config->id));
+
+  return OK;
+}
+
+/****************************************************************************
+ * Name: esp32s3_spi_dma_deinit
+ *
+ * Description:
+ *   Deinitialize ESP32-S3 SPI GDMA engine.
+ *
+ * Input Parameters:
+ *   dev - Device-specific state data
+ *
+ * Returned Value:
+ *   None.
+ *
+ ****************************************************************************/
+
+void esp32s3_spi_dma_deinit(struct spi_dev_s *dev)
+{
+  struct esp32s3_spi_priv_s *priv = (struct esp32s3_spi_priv_s *)dev;
+
+  /* Release a DMA channel from peripheral */
+
+  esp32s3_dma_release(priv->dma_channel);
+
+  /* Deinitialize DMA controller */
+
+  esp32s3_dma_deinit();
+
+  /* Disable DMA clock for the SPI peripheral */
+
+  modifyreg32(SYSTEM_PERIP_CLK_EN0_REG, priv->config->dma_clk_bit, 0);
 }
 #endif
 
@@ -1349,14 +1412,14 @@ void esp32s3_spi_dma_init(struct spi_dev_s *dev)
  *   Initialize ESP32-S3 SPI hardware interface.
  *
  * Input Parameters:
- *   dev      - Device-specific state data
+ *   dev - Device-specific state data
  *
  * Returned Value:
- *   None.
+ *   OK on success; A negated errno value on failure.
  *
  ****************************************************************************/
 
-static void esp32s3_spi_init(struct spi_dev_s *dev)
+static int esp32s3_spi_init(struct spi_dev_s *dev)
 {
   struct esp32s3_spi_priv_s *priv = (struct esp32s3_spi_priv_s *)dev;
   const struct esp32s3_spi_config_s *config = priv->config;
@@ -1427,12 +1490,19 @@ static void esp32s3_spi_init(struct spi_dev_s *dev)
            SPI_USER1_REG(priv->config->id));
 
 #ifdef CONFIG_ESP32S3_SPI_DMA
-  esp32s3_spi_dma_init(dev);
+  if (esp32s3_spi_dma_init(dev) != OK)
+    {
+      modifyreg32(SYSTEM_PERIP_RST_EN0_REG, 0, priv->config->clk_bit);
+      modifyreg32(SYSTEM_PERIP_CLK_EN0_REG, priv->config->clk_bit, 0);
+      return ERROR;
+    }
 #endif
 
   esp32s3_spi_setfrequency(dev, config->clk_freq);
   esp32s3_spi_setbits(dev, config->width);
   esp32s3_spi_setmode(dev, config->mode);
+
+  return OK;
 }
 
 /****************************************************************************
@@ -1442,7 +1512,7 @@ static void esp32s3_spi_init(struct spi_dev_s *dev)
  *   Deinitialize ESP32-S3 SPI hardware interface.
  *
  * Input Parameters:
- *   dev      - Device-specific state data
+ *   dev - Device-specific state data
  *
  * Returned Value:
  *   None.
@@ -1454,7 +1524,7 @@ static void esp32s3_spi_deinit(struct spi_dev_s *dev)
   struct esp32s3_spi_priv_s *priv = (struct esp32s3_spi_priv_s *)dev;
 
 #ifdef CONFIG_ESP32S3_SPI_DMA
-  modifyreg32(SYSTEM_PERIP_CLK_EN0_REG, priv->config->dma_clk_bit, 0);
+  esp32s3_spi_dma_deinit(dev);
 #endif
 
   modifyreg32(SYSTEM_PERIP_RST_EN0_REG, 0, priv->config->clk_bit);
@@ -1504,7 +1574,7 @@ static int esp32s3_spi_interrupt(int irq, void *context, void *arg)
  *   Initialize the selected SPI bus.
  *
  * Input Parameters:
- *   port     - Port number (for hardware that has multiple SPI interfaces)
+ *   port - Port number (for hardware that has multiple SPI interfaces)
  *
  * Returned Value:
  *   Valid SPI device structure reference on success; NULL on failure.
@@ -1589,7 +1659,18 @@ struct spi_dev_s *esp32s3_spibus_initialize(int port)
   up_enable_irq(priv->config->irq);
 #endif
 
-  esp32s3_spi_init(spi_dev);
+  if (esp32s3_spi_init(spi_dev) != OK)
+    {
+#ifdef CONFIG_ESP32S3_SPI_DMA
+      up_disable_irq(priv->config->irq);
+      esp32s3_teardown_irq(priv->cpu, priv->config->periph, priv->cpuint);
+      irq_detach(priv->config->irq);
+      priv->cpuint = -ENOMEM;
+#endif
+      nxmutex_unlock(&priv->lock);
+      return NULL;
+    }
+
   priv->refs++;
 
   nxmutex_unlock(&priv->lock);
@@ -1603,7 +1684,7 @@ struct spi_dev_s *esp32s3_spibus_initialize(int port)
  *   Uninitialize an SPI bus.
  *
  * Input Parameters:
- *   dev      - Device-specific state data
+ *   dev - Device-specific state data
  *
  * Returned Value:
  *   Zero (OK) is returned on success. Otherwise -1 (ERROR).
