@@ -31,10 +31,6 @@
 #  include <stdint.h>
 #endif
 
-#include "stm32_rcc.h"
-#include "stm32_sdio.h"
-#include "stm32.h"
-
 /****************************************************************************
  * Pre-processor Definitions
  ****************************************************************************/
