@@ -227,5 +227,18 @@ int board_ws2812_initialize(
 #    endif
 #  endif
 
+/****************************************************************************
+ * Name:  openeth_initialize
+ *
+ * Description:
+ *   This function may called from application-specific logic during its
+ *   to perform board-specific initialization of the Open ETH interface
+ *
+ *
+ ****************************************************************************/
+#ifdef CONFIG_ESP32_OPENETH
+int esp32_openeth_initialize(void);
+#endif
+
 #endif /* __ASSEMBLY__ */
 #endif /* __BOARDS_XTENSA_ESP32_ESP32_DEVKITC_SRC_ESP32_DEVKITC_H */
