@@ -165,6 +165,10 @@
 #  include "esp32_rmt.h"
 #endif
 
+#ifdef CONFIG_DAC
+#  include "esp32_board_dac.h"
+#endif
+
 #include "esp32-devkitc.h"
 
 /****************************************************************************
@@ -332,6 +336,14 @@ int esp32_bringup(void)
     }
 #endif
 
+#ifdef CONFIG_ESP32_OPENETH
+  ret = esp32_openeth_initialize();
+  if (ret < 0)
+    {
+      syslog(LOG_ERR, "ERROR: Failed to initialize Open ETH ethernet.\n");
+    }
+#endif
+
   /* First, register the timer drivers and let timer 1 for oneshot
    * if it is enabled.
    */
@@ -645,6 +657,14 @@ int esp32_bringup(void)
     }
 #endif
 
+#ifdef CONFIG_DAC
+  ret = board_dac_initialize(CONFIG_ESP32_DAC_DEVPATH);
+  if (ret < 0)
+    {
+      syslog(LOG_ERR, "ERROR: board_dac_initialize(0) failed: %d\n", ret);
+    }
+#endif
+
 #ifdef CONFIG_RTC_DRIVER
   /* Instantiate the ESP32 RTC driver */
 
