@@ -82,6 +82,15 @@ int board_wdt_init(void)
     }
 #endif /* CONFIG_ESP32S3_RWDT */
 
+#ifdef CONFIG_ESP32S3_XTWDT
+  ret = esp32s3_wdt_initialize("/dev/watchdog3", ESP32S3_WDT_XTWDT);
+  if (ret < 0)
+    {
+      syslog(LOG_ERR, "Failed to initialize XTWDT: %d\n", ret);
+      return ret;
+    }
+#endif /* CONFIG_ESP32S3_XTWDT */
+
   return ret;
 }
 
