@@ -44,6 +44,26 @@
 
 #define BUTTON_BOOT  0
 
+/* RMT gpio */
+
+#define RMT_RXCHANNEL       4
+#define RMT_TXCHANNEL       0
+
+#ifdef CONFIG_RMT_LOOP_TEST_MODE
+#  define RMT_INPUT_PIN       0
+#  define RMT_OUTPUT_PIN      0
+#else
+#  define RMT_INPUT_PIN       2
+
+/* The on-board RGB LED pin differs depending on the board version */
+
+#  ifdef CONFIG_ESP32S3_DEVKITC_1_V10
+#    define RMT_OUTPUT_PIN      48
+#  else
+#    define RMT_OUTPUT_PIN      38
+#  endif
+#endif
+
 /****************************************************************************
  * Public Types
  ****************************************************************************/
@@ -210,5 +230,26 @@ int esp32s3_pwm_setup(void);
 int esp32s3_twai_setup(void);
 #endif
 
+/****************************************************************************
+ * Name: esp32s3_lan9250_initialize
+ *
+ * Description:
+ *   This function is called by platform-specific setup logic to initialize
+ *   the LAN9250 device. This function will register the driver
+ *   as a network device.
+ *
+ * Input Parameters:
+ *   port - The SPI port used for the device
+ *
+ * Returned Value:
+ *   Zero is returned on success. Otherwise, a negated errno value is
+ *   returned to indicate the nature of the failure.
+ *
+ ****************************************************************************/
+
+#ifdef CONFIG_NET_LAN9250
+int esp32s3_lan9250_initialize(int port);
+#endif
+
 #endif /* __ASSEMBLY__ */
 #endif /* __BOARDS_XTENSA_ESP32S3_ESP32S3_DEVKIT_SRC_ESP32S3_DEVKIT_H */
