@@ -49,7 +49,7 @@ static int opamp_ioctl(FAR struct file *filep, int cmd, unsigned long arg);
  * Private Data
  ****************************************************************************/
 
-static const struct file_operations opamp_fops =
+static const struct file_operations g_opamp_fops =
 {
   opamp_open,                    /* open */
   opamp_close,                   /* close */
@@ -209,7 +209,7 @@ int opamp_register(FAR const char *path, FAR struct opamp_dev_s *dev)
 
   /* Register the OPAMP character driver */
 
-  ret = register_driver(path, &opamp_fops, 0444, dev);
+  ret = register_driver(path, &g_opamp_fops, 0444, dev);
   if (ret < 0)
     {
       nxmutex_destroy(&dev->ad_closelock);
