@@ -1310,7 +1310,7 @@ FAR struct audio_lowerhalf_s *
 
   /* Allocate a WM8776 device structure */
 
-  priv = (FAR struct wm8776_dev_s *)kmm_zalloc(sizeof(struct wm8776_dev_s));
+  priv = kmm_zalloc(sizeof(struct wm8776_dev_s));
 
   if (priv)
     {
