@@ -35,6 +35,7 @@
 #include <debug.h>
 
 #include <nuttx/arch.h>
+#include <nuttx/bits.h>
 #include <nuttx/spi/spi.h>
 #include <nuttx/lcd/lcd.h>
 #include <nuttx/lcd/max7219.h>
@@ -119,11 +120,6 @@
 #define LS_BIT               (1 << 0)
 #define MS_BIT               (1 << 7)
 
-#define BIT(nr)              (1 << (nr))
-#define BITS_PER_BYTE         8
-#define BIT_MASK(nr)         (1 << ((nr) % BITS_PER_BYTE))
-#define BIT_BYTE(nr)         ((nr) / BITS_PER_BYTE)
-
 /****************************************************************************
  * Private Type Definition
  ****************************************************************************/
@@ -289,14 +285,14 @@ static struct max7219_dev_s g_max7219dev =
 
 static inline void __set_bit(int nr, uint8_t * addr)
 {
-  uint8_t mask = BIT_MASK(nr);
+  uint8_t mask = BIT_BYTE_MASK(nr);
   uint8_t *p = ((uint8_t *) addr) + BIT_BYTE(nr);
   *p |= mask;
 }
 
 static inline void __clear_bit(int nr, uint8_t * addr)
 {
-  uint8_t mask = BIT_MASK(nr);
+  uint8_t mask = BIT_BYTE_MASK(nr);
   uint8_t *p = ((uint8_t *) addr) + BIT_BYTE(nr);
   *p &= ~mask;
 }
