@@ -916,6 +916,7 @@ static int lp503x_ioctl(struct file *filep, int cmd,
 int lp503x_register(const char *devpath, struct i2c_master_s *i2c,
                     uint8_t const lp503x_i2c_addr, int const i2c_frequency)
 {
+  struct lp503x_dev_s *priv;
   int ret;
 
   /* Sanity check */
@@ -924,9 +925,7 @@ int lp503x_register(const char *devpath, struct i2c_master_s *i2c,
 
   /* Initialize the LP503X device structure */
 
-  struct lp503x_dev_s *priv =
-         (struct lp503x_dev_s *)kmm_malloc(sizeof(struct lp503x_dev_s));
-
+  priv = kmm_malloc(sizeof(struct lp503x_dev_s));
   if (priv == NULL)
     {
       lederr("ERROR: Failed to allocate instance of lp503x_dev_s\n");
