@@ -144,6 +144,16 @@ static void rwb_wrflush(FAR struct rwbuffer_s *rwb)
       finfo("Flushing: blockstart=0x%08lx nblocks=%d from buffer=%p\n",
             (long)rwb->wrblockstart, rwb->wrnblocks, rwb->wrbuffer);
 
+      padblocks = rwb->wrblockstart % rwb->wralignblocks;
+      if (padblocks)
+        {
+          memmove(rwb->wrbuffer + padblocks * rwb->blocksize,
+                  rwb->wrbuffer, rwb->wrnblocks * rwb->blocksize);
+          rwb->wrblockstart -= padblocks;
+          rwb->wrnblocks += padblocks;
+          rwb_read_(rwb, rwb->wrblockstart, padblocks, rwb->wrbuffer);
+        }
+
       padblocks = rwb->wrnblocks % rwb->wralignblocks;
       if (padblocks)
         {
@@ -911,7 +921,7 @@ static ssize_t rwb_read_(FAR struct rwbuffer_s *rwb, off_t startblock,
     {
       size_t remaining;
 
-      ret = nxmutex_lock(&rwb->rhlock);
+      ret = rwb_lock(&rwb->rhlock);
       if (ret < 0)
         {
           return ret;
@@ -1005,7 +1015,7 @@ ssize_t rwb_read(FAR struct rwbuffer_s *rwb, off_t startblock,
 
   if (rwb->wrmaxblocks > 0)
     {
-      ret = nxmutex_lock(&rwb->wrlock);
+      ret = rwb_lock(&rwb->wrlock);
       if (ret < 0)
         {
           return ret;
@@ -1082,7 +1092,7 @@ ssize_t rwb_write(FAR struct rwbuffer_s *rwb, off_t startblock,
        * streaming applications.
        */
 
-      ret = nxmutex_lock(&rwb->rhlock);
+      ret = rwb_lock(&rwb->rhlock);
       if (ret < 0)
         {
           return ret;
@@ -1115,7 +1125,7 @@ ssize_t rwb_write(FAR struct rwbuffer_s *rwb, off_t startblock,
     {
       finfo("startblock=%" PRIdOFF " wrbuffer=%p\n", startblock, wrbuffer);
 
-      ret = nxmutex_lock(&rwb->wrlock);
+      ret = rwb_lock(&rwb->wrlock);
       if (ret < 0)
         {
           return ret;
