@@ -51,9 +51,9 @@
 #define ALTCOM_RX_PKT_SIZE_MAX     (ALTCOM_PAYLOAD_SIZE_MAX_V4 \
                                     + sizeof(struct altcom_cmdhdr_s))
 
-#define LTE_RESULT_OK     (0)      /**< Result code on success */
-#define LTE_RESULT_ERROR  (1)      /**< Result code on failure */
-#define LTE_RESULT_CANCEL (2)      /**< Result code on cancel */
+#define LTE_RESULT_OK     (0)      /* Result code on success */
+#define LTE_RESULT_ERROR  (1)      /* Result code on failure */
+#define LTE_RESULT_CANCEL (2)      /* Result code on cancel */
 
 #define ALTCOM_CMD_POWER_ON_REPLY_SIZE  (1)
 
