@@ -965,7 +965,7 @@ FAR struct mtd_dev_s *sst26_initialize_spi(FAR struct spi_dev_s *dev,
    * have to be extended to handle multiple FLASH parts on the same SPI bus.
    */
 
-  priv = (FAR struct sst26_dev_s *)kmm_zalloc(sizeof(struct sst26_dev_s));
+  priv = kmm_zalloc(sizeof(struct sst26_dev_s));
   if (priv)
     {
       /* Initialize the allocated structure. (unsupported methods were
