@@ -57,7 +57,7 @@ static int     smps_ioctl(FAR struct file *filep, int cmd,
  * Private Data
  ****************************************************************************/
 
-static const struct file_operations smps_fops =
+static const struct file_operations g_smps_fops =
 {
   smps_open,                    /* open */
   smps_close,                   /* close */
@@ -509,7 +509,7 @@ int smps_register(FAR const char *path, FAR struct smps_dev_s *dev,
 
   /* Register the SMPS character driver */
 
-  ret = register_driver(path, &smps_fops, 0666, dev);
+  ret = register_driver(path, &g_smps_fops, 0666, dev);
   if (ret < 0)
     {
       nxmutex_destroy(&dev->closelock);
