@@ -285,32 +285,21 @@ static int pty_open(FAR struct file *filep)
         }
     }
 
-  /* If one side of the driver has been unlinked, then refuse further
-   * opens.
-   */
+  /* First open? */
 
-  if (devpair->pp_unlinked)
+  if (devpair->pp_nopen == 0)
     {
-      ret = -EIDRM;
+      /* Yes, create the internal pipe */
+
+      ret = pty_pipe(devpair);
     }
-  else
+
+  /* Increment the count of open references on the driver */
+
+  if (ret >= 0)
     {
-      /* First open? */
-
-      if (devpair->pp_nopen == 0)
-        {
-          /* Yes, create the internal pipe */
-
-          ret = pty_pipe(devpair);
-        }
-
-      /* Increment the count of open references on the driver */
-
-      if (ret >= 0)
-        {
-          devpair->pp_nopen++;
-          DEBUGASSERT(devpair->pp_nopen > 0);
-        }
+      devpair->pp_nopen++;
+      DEBUGASSERT(devpair->pp_nopen > 0);
     }
 
   nxmutex_unlock(&devpair->pp_lock);
@@ -318,7 +307,7 @@ static int pty_open(FAR struct file *filep)
 }
 
 /****************************************************************************
- * Name: pty_open
+ * Name: pty_close
  ****************************************************************************/
 
 static int pty_close(FAR struct file *filep)
@@ -372,6 +361,7 @@ static int pty_close(FAR struct file *filep)
     {
       /* Yes.. Free the device pair now (without freeing the semaphore) */
 
+      nxmutex_unlock(&devpair->pp_lock);
       pty_destroy(devpair);
       return OK;
     }
@@ -961,6 +951,7 @@ static int pty_unlink(FAR struct inode *inode)
 
   if (devpair->pp_nopen == 0)
     {
+      nxmutex_unlock(&devpair->pp_lock);
       pty_destroy(devpair);
       return OK;
     }
