@@ -52,6 +52,14 @@
 
 #ifdef CONFIG_16550_UART
 
+/****************************************************************************
+ * Pre-processor Definitions
+ ****************************************************************************/
+
+/* Timeout for UART Busy Wait, in milliseconds */
+
+#define UART_TIMEOUT_MS 100
+
 /****************************************************************************
  * Private Types
  ****************************************************************************/
@@ -622,6 +630,43 @@ static inline void u16550_serialout(FAR struct u16550_s *priv, int offset,
 #endif
 }
 
+#ifdef CONFIG_16550_WAIT_LCR
+/****************************************************************************
+ * Name: u16550_wait
+ *
+ * Description:
+ *   Wait until UART is not busy. This is needed before writing to LCR.
+ *   Otherwise we will get spurious interrupts on Synopsys DesignWare 8250.
+ *
+ * Input Parameters:
+ *   priv: UART Struct
+ *
+ * Returned Value:
+ *   Zero (OK) on success; ERROR if timeout.
+ *
+ ****************************************************************************/
+
+static int u16550_wait(FAR struct u16550_s *priv)
+{
+  int i;
+
+  for (i = 0; i < UART_TIMEOUT_MS; i++)
+    {
+      uint32_t status = u16550_serialin(priv, UART_USR_OFFSET);
+
+      if ((status & UART_USR_BUSY) == 0)
+        {
+          return OK;
+        }
+
+      up_mdelay(1);
+    }
+
+  _err("UART timeout\n");
+  return ERROR;
+}
+#endif /* CONFIG_16550_WAIT_LCR */
+
 /****************************************************************************
  * Name: u16550_disableuartint
  ****************************************************************************/
@@ -667,6 +712,15 @@ static inline void u16550_enablebreaks(FAR struct u16550_s *priv,
       lcr &= ~UART_LCR_BRK;
     }
 
+#ifdef CONFIG_16550_WAIT_LCR
+  /* Wait till UART is not busy before setting LCR */
+
+  if (u16550_wait(priv) < 0)
+    {
+      _err("UART wait failed\n");
+    }
+#endif /* CONFIG_16550_WAIT_LCR */
+
   u16550_serialout(priv, UART_LCR_OFFSET, lcr);
 }
 
@@ -761,6 +815,16 @@ static int u16550_setup(FAR struct uart_dev_s *dev)
       lcr |= (UART_LCR_PEN | UART_LCR_EPS);
     }
 
+#ifdef CONFIG_16550_WAIT_LCR
+  /* Wait till UART is not busy before setting LCR */
+
+  if (u16550_wait(priv) < 0)
+    {
+      _err("UART wait failed\n");
+      return ERROR;
+    }
+#endif /* CONFIG_16550_WAIT_LCR */
+
   /* Enter DLAB=1 */
 
   u16550_serialout(priv, UART_LCR_OFFSET, (lcr | UART_LCR_DLAB));
@@ -771,6 +835,16 @@ static int u16550_setup(FAR struct uart_dev_s *dev)
   u16550_serialout(priv, UART_DLM_OFFSET, div >> 8);
   u16550_serialout(priv, UART_DLL_OFFSET, div & 0xff);
 
+#ifdef CONFIG_16550_WAIT_LCR
+  /* Wait till UART is not busy before setting LCR */
+
+  if (u16550_wait(priv) < 0)
+    {
+      _err("UART wait failed\n");
+      return ERROR;
+    }
+#endif /* CONFIG_16550_WAIT_LCR */
+
   /* Clear DLAB */
 
   u16550_serialout(priv, UART_LCR_OFFSET, lcr);
