@@ -74,6 +74,7 @@
 #include <limits.h>
 #include <nuttx/mutex.h>
 
+#include <nuttx/bits.h>
 #include <nuttx/compiler.h>
 #include <nuttx/kmalloc.h>
 #include <nuttx/spi/spi.h>
@@ -88,10 +89,6 @@
 
 #define DEBUG 1
 
-/* Sets bit @n */
-
-#define BIT(n) (1 << (n))
-
 /* Creates a mask of @m bits, i.e. MASK(2) -> 00000011 */
 
 #define MASK(m) (BIT((m) + 1) - 1)
