@@ -29,6 +29,7 @@
 #include "rpmsgfs/rpmsgfs.h"
 #include "inode/inode.h"
 #include "aio/aio.h"
+#include "vfs/lock.h"
 
 /****************************************************************************
  * Private Functions
@@ -83,6 +84,8 @@ void fs_initialize(void)
 
   inode_initialize();
 
+  file_initlk();
+
 #ifdef CONFIG_FS_AIO
   /* Initialize for asynchronous I/O */
 
