@@ -69,11 +69,6 @@ static int _inode_compare(FAR const char *fname, FAR struct inode *node)
 {
   FAR char *nname = node->i_name;
 
-  if (!nname)
-    {
-      return 1;
-    }
-
   if (!fname)
     {
       return -1;
@@ -219,7 +214,7 @@ static int _inode_linktarget(FAR struct inode *node,
 static int _inode_search(FAR struct inode_search_s *desc)
 {
   FAR const char   *name;
-  FAR struct inode *node    = g_root_inode;
+  FAR struct inode *node    = inode_root();
   FAR struct inode *left    = NULL;
   FAR struct inode *above   = NULL;
   FAR const char   *relpath = NULL;
