@@ -71,7 +71,7 @@
            nxrmutex_unlock(&tdo->tdo_lock)
 
 /****************************************************************************
- * Private Type
+ * Private Types
  ****************************************************************************/
 
 struct tmpfs_dir_s
@@ -181,6 +181,7 @@ const struct mountpt_operations g_tmpfs_operations =
   NULL,             /* ioctl */
   tmpfs_mmap,       /* mmap */
   tmpfs_truncate,   /* truncate */
+  NULL,             /* poll */
 
   tmpfs_sync,       /* sync */
   tmpfs_dup,        /* dup */
@@ -298,6 +299,12 @@ static int tmpfs_realloc_file(FAR struct tmpfs_file_s *tfo,
    */
 
   allocsize = newsize + CONFIG_FS_TMPFS_FILE_ALLOCGUARD;
+  if (allocsize < newsize)
+    {
+      /* There must have been an integer overflow */
+
+      return -ENOMEM;
+    }
 
   /* Realloc the file object */
 
