@@ -38,10 +38,10 @@
  * Pre-processor Definitions
  ****************************************************************************/
 
-#if CONFIG_MM_DFAULT_ALIGNMENT == 0
+#if CONFIG_MM_DEFAULT_ALIGNMENT == 0
 #  define MEMPOOL_ALIGN       (2 * sizeof(uintptr_t))
 #else
-#  define MEMPOOL_ALIGN       CONFIG_MM_DFAULT_ALIGNMENT
+#  define MEMPOOL_ALIGN       CONFIG_MM_DEFAULT_ALIGNMENT
 #endif
 
 #if CONFIG_MM_BACKTRACE >= 0
