@@ -30,6 +30,8 @@
 #include <nuttx/mutex.h>
 #include <nuttx/semaphore.h>
 
+#include <nuttx/motor/foc/foc_pwr.h>
+
 #include <stdbool.h>
 
 #include <fixedmath.h>
@@ -46,6 +48,8 @@
 #define FOCDUTY_TO_FLOAT(d)     (b16tof(d))
 #define FOCDUTY_TO_FIXED16(d)   (d)
 
+#define FOC_BOARDCFG_GAINLIST_LEN 4
+
 /****************************************************************************
  * Public Types
  ****************************************************************************/
@@ -98,19 +102,52 @@ struct foc_params_s
   foc_duty_t duty[CONFIG_MOTOR_FOC_PHASES]; /* PWM duty cycle for phases */
 };
 
-/* Hardware specific configuration */
+/* Hardware specific informations */
 
-struct foc_hw_config_s
+struct foc_info_hw_s
 {
+  /* PWM configuration */
+
   uint32_t   pwm_dt_ns;   /* PWM dead-time in nano seconds */
   foc_duty_t pwm_max;     /* Maximum PWM duty cycle */
+
+  /* ADC configuration for phase current sampling
+   *
+   * In most cases it will be:
+   *
+   *   iphase_scale = iphase_ratio * adc_to_volt
+   *   adc_to_volt  = adc_ref_volt / adc_val_max
+   *   for shunt sensors iphase_ratio = 1 / (R_shunt * gain)
+   */
+
+  int32_t    iphase_scale;              /* Current phase scale [x100000] */
+  int32_t    iphase_max;                /* Maximum phase curretn [x1000] */
+
+  /* ADC configuration for BEMF sampling */
+
+#ifdef CONFIG_MOTOR_FOC_BEMF_SENSE
+  int32_t    bemf_scale;                /* BEMF sampling scale [x1000] */
+#endif
 };
 
 /* FOC driver info */
 
 struct foc_info_s
 {
-  struct foc_hw_config_s hw_cfg; /* Hardware specific configuration */
+  struct foc_info_hw_s hw_cfg; /* Hardware specific informations  */
+};
+
+/* FOC board-specific configuration */
+
+struct foc_set_boardcfg_s
+{
+  int gain;
+};
+
+struct foc_get_boardcfg_s
+{
+  int gain;
+  int gain_list[FOC_BOARDCFG_GAINLIST_LEN];
 };
 
 /* FOC device upper-half */
@@ -140,6 +177,10 @@ struct foc_dev_s
   /* FOC device input/output data *******************************************/
 
   struct foc_state_s         state;      /* FOC device state */
+
+  /* (Optional) FOC power-stage driver  *************************************/
+
+  FAR struct focpwr_dev_s    *pwr;        /* FOC power-stage driver */
 };
 
 /****************************************************************************
