@@ -259,12 +259,9 @@ int netdev_lower_unregister(FAR struct netdev_lowerhalf_s *dev);
  * Input Parameters:
  *   dev - The lower half device driver structure
  *
- * Returned Value:
- *   0:Success; negated errno on failure
- *
  ****************************************************************************/
 
-int netdev_lower_carrier_on(FAR struct netdev_lowerhalf_s *dev);
+void netdev_lower_carrier_on(FAR struct netdev_lowerhalf_s *dev);
 
 /****************************************************************************
  * Name: netdev_lower_carrier_off
@@ -276,12 +273,9 @@ int netdev_lower_carrier_on(FAR struct netdev_lowerhalf_s *dev);
  * Input Parameters:
  *   dev - The lower half device driver structure
  *
- * Returned Value:
- *   0:Success; negated errno on failure
- *
  ****************************************************************************/
 
-int netdev_lower_carrier_off(FAR struct netdev_lowerhalf_s *dev);
+void netdev_lower_carrier_off(FAR struct netdev_lowerhalf_s *dev);
 
 /****************************************************************************
  * Name: netdev_lower_rxready
