@@ -27,6 +27,7 @@
 
 #include <nuttx/config.h>
 #include <nuttx/notifier.h>
+#include <nuttx/sched.h>
 
 #include <sys/types.h>
 
@@ -41,6 +42,17 @@ enum panic_type_e
   PANIC_KERNEL_FINAL   =  2,
 };
 
+/* Notifier data for panic */
+
+struct panic_notifier_s
+{
+  FAR struct tcb_s *rtcb;
+  FAR void         *regs;
+  FAR const char   *msg;
+  FAR const char   *filename;
+  int               linenum;
+};
+
 /****************************************************************************
  * Public Function
  ****************************************************************************/
