@@ -290,6 +290,14 @@
 #define dq_inqueue(p, q) \
       ((p)->flink || dq_tail(q) == (p))
 
+/* sq/dq_is_singular - tests whether a list has just one entry.  */
+
+#define sq_is_singular(q) \
+      (!sq_empty(q) && (q)->head->flink == NULL)
+
+#define dq_is_singular(q) \
+      (!dq_empty(q) && (q)->head->flink == NULL)
+
 /****************************************************************************
  * Public Type Definitions
  ****************************************************************************/
