@@ -71,7 +71,7 @@ int puts(FAR const IPTR char *s)
 
           if ((stream->fs_flags & __FS_FLAG_LBF) != 0)
             {
-              ret = lib_fflush_unlocked(stream, true);
+              ret = lib_fflush_unlocked(stream);
               if (ret < 0)
                 {
                   nput = EOF;
