@@ -128,9 +128,12 @@ struct arp_iphdr_s
  * operated upon from the network driver poll.
  */
 
+typedef CODE void (*arp_send_finish_cb_t)(FAR struct net_driver_s *dev,
+                                          int result);
 struct arp_send_s
 {
   FAR struct devif_callback_s *snd_cb; /* Reference to callback instance */
+  FAR arp_send_finish_cb_t finish_cb;  /* Reference to send finish callback */
   sem_t     snd_sem;                   /* Used to wake up the waiting thread */
   uint8_t   snd_retries;               /* Retry count */
   volatile bool snd_sent;              /* True: if request sent */
@@ -275,6 +278,33 @@ int arp_send(in_addr_t ipaddr);
 #  define arp_send(i) (0)
 #endif
 
+/****************************************************************************
+ * Name: arp_send_async
+ *
+ * Description:
+ *   The arp_send_async() call may be to send an ARP request asyncly to
+ *   resolve an IPv4 address.
+ *
+ * Input Parameters:
+ *   ipaddr   The IP address to be queried.
+ *   cb       The callback when ARP send is finished, should not be NULL.
+ *
+ * Returned Value:
+ *   Zero (OK) is returned on success the arp been sent to the driver.
+ *   On error a negated errno value is returned:
+ *
+ *     -ETIMEDOUT:    The number or retry counts has been exceed.
+ *     -EHOSTUNREACH: Could not find a route to the host
+ *
+ * Assumptions:
+ *   This function is called from the normal tasking context.
+ *
+ ****************************************************************************/
+
+#ifdef CONFIG_NET_ARP_SEND
+int arp_send_async(in_addr_t ipaddr, arp_send_finish_cb_t cb);
+#endif
+
 /****************************************************************************
  * Name: arp_poll
  *
@@ -523,6 +553,58 @@ void arp_dump(FAR struct arp_hdr_s *arp);
 #  define arp_dump(arp)
 #endif
 
+#ifdef CONFIG_NET_ARP_ACD
+
+/****************************************************************************
+ * Name: arp_acd_update
+ *
+ * Description:
+ *   interface of ARP Address Conflict Detection monitor
+ *
+ * Input Parameters:
+ *   dev - The device driver structure to use in the send operation
+ *
+ * Returned Value:
+ *   none
+ *
+ ****************************************************************************/
+
+void arp_acd_update(FAR struct net_driver_s *dev);
+
+/****************************************************************************
+ * Name: arp_acd_set_addr
+ *
+ * Description:
+ *   setting address interface of ARP Address Conflict Detection
+ *
+ * Input Parameters:
+ *   dev - The device driver structure to use in the send operation
+ *
+ * Returned Value:
+ *   none
+ *
+ ****************************************************************************/
+
+void arp_acd_set_addr(FAR struct net_driver_s *dev);
+
+/****************************************************************************
+ * Name: arp_acd_setup
+ *
+ * Description:
+ *   set up interface of ARP Address Conflict Detection
+ *
+ * Input Parameters:
+ *   dev - The device driver structure to use in the send operation
+ *
+ * Returned Value:
+ *   none
+ *
+ ****************************************************************************/
+
+void arp_acd_setup(FAR struct net_driver_s *dev);
+
+#endif /* CONFIG_NET_ARP_ACD */
+
 #else /* CONFIG_NET_ARP */
 
 /* If ARP is disabled, stub out all ARP interfaces */
