@@ -23,7 +23,6 @@
  ****************************************************************************/
 
 #include <nuttx/config.h>
-#if defined(CONFIG_NET) && defined(CONFIG_NET_LOCAL)
 
 #include <sys/param.h>
 #include <sys/types.h>
@@ -237,13 +236,19 @@ psock_stream_recvfrom(FAR struct socket *psock, FAR void *buf, size_t len,
 
   /* Verify that this is a connected peer socket */
 
-  if (conn->lc_state != LOCAL_STATE_CONNECTED ||
-      conn->lc_infile.f_inode == NULL)
+  if (conn->lc_state != LOCAL_STATE_CONNECTED)
     {
       nerr("ERROR: not connected\n");
       return -ENOTCONN;
     }
 
+  /* Check shutdown state */
+
+  if (conn->lc_infile.f_inode == NULL)
+    {
+      return 0;
+    }
+
   /* If it is non-blocking mode, the data in fifo is 0 and
    * returns directly
    */
@@ -368,7 +373,6 @@ psock_dgram_recvfrom(FAR struct socket *psock, FAR void *buf, size_t len,
   if (conn->pktlen <= 0)
     {
       ret = local_sync(&conn->lc_infile);
-
       if (ret < 0)
         {
           nerr("ERROR: Failed to get packet length: %d\n", ret);
@@ -467,7 +471,7 @@ errout_with_halfduplex:
 
   return ret < 0 ? ret : readlen;
 }
-#endif /* CONFIG_NET_LOCAL_STREAM */
+#endif /* CONFIG_NET_LOCAL_DGRAM */
 
 /****************************************************************************
  * Public Functions
@@ -543,5 +547,3 @@ ssize_t local_recvmsg(FAR struct socket *psock, FAR struct msghdr *msg,
 
   return len;
 }
-
-#endif /* CONFIG_NET && CONFIG_NET_LOCAL */
