@@ -90,7 +90,7 @@ size_t group_argvstr(FAR struct tcb_s *tcb, FAR char *args, size_t size)
   else
 #endif
     {
-      FAR char **argv = tcb->group->tg_info->argv + 1;
+      FAR char **argv = tcb->group->tg_info->ta_argv + 1;
 
       while (*argv != NULL && n < size)
         {
