@@ -39,24 +39,10 @@
 #include "group/group.h"
 #include "tls/tls.h"
 
-/****************************************************************************
- * Pre-processor Definitions
- ****************************************************************************/
-
-/* Is this worth making a configuration option? */
-
-#define GROUP_INITIAL_MEMBERS 4
-
 /****************************************************************************
  * Public Data
  ****************************************************************************/
 
-#if defined(HAVE_GROUP_MEMBERS)
-/* This is the head of a list of all group members */
-
-FAR struct task_group_s *g_grouphead;
-#endif
-
 /****************************************************************************
  * Private Functions
  ****************************************************************************/
@@ -102,7 +88,7 @@ static inline void group_inherit_identity(FAR struct task_group_s *group)
  ****************************************************************************/
 
 /****************************************************************************
- * Name: group_allocate
+ * Name: group_initialize
  *
  * Description:
  *   Create and a new task group structure for the specified TCB. This
@@ -110,8 +96,8 @@ static inline void group_inherit_identity(FAR struct task_group_s *group)
  *   allocated and zeroed, but otherwise uninitialized.  The full creation
  *   of the group of a two step process:  (1) First, this function allocates
  *   group structure early in the task creation sequence in order to provide
- *   a group container, then (2) group_initialize() is called to set up the
- *   group membership.
+ *   a group container, then (2) group_postinitialize() is called to set up
+ *   the group membership.
  *
  * Input Parameters:
  *   tcb   - The tcb in need of the task group.
@@ -126,7 +112,7 @@ static inline void group_inherit_identity(FAR struct task_group_s *group)
  *
  ****************************************************************************/
 
-int group_allocate(FAR struct task_tcb_s *tcb, uint8_t ttype)
+int group_initialize(FAR struct task_tcb_s *tcb, uint8_t ttype)
 {
   FAR struct task_group_s *group;
   int ret;
@@ -135,11 +121,7 @@ int group_allocate(FAR struct task_tcb_s *tcb, uint8_t ttype)
 
   /* Allocate the group structure and assign it to the TCB */
 
-  group = kmm_zalloc(sizeof(struct task_group_s));
-  if (!group)
-    {
-      return -ENOMEM;
-    }
+  group = &tcb->group;
 
 #if defined(CONFIG_MM_KERNEL_HEAP)
   /* If this group is being created for a privileged thread, then all
@@ -153,18 +135,9 @@ int group_allocate(FAR struct task_tcb_s *tcb, uint8_t ttype)
 #endif /* defined(CONFIG_MM_KERNEL_HEAP) */
 
 #ifdef HAVE_GROUP_MEMBERS
-  /* Allocate space to hold GROUP_INITIAL_MEMBERS members of the group */
+  /* Initialize member list of the group */
 
-  group->tg_members = kmm_malloc(GROUP_INITIAL_MEMBERS * sizeof(pid_t));
-  if (!group->tg_members)
-    {
-      ret = -ENOMEM;
-      goto errout_with_group;
-    }
-
-  /* Number of members in allocation */
-
-  group->tg_mxmembers = GROUP_INITIAL_MEMBERS;
+  sq_init(&group->tg_members);
 #endif
 
   /* Attach the group to the TCB */
@@ -184,13 +157,14 @@ int group_allocate(FAR struct task_tcb_s *tcb, uint8_t ttype)
   ret = task_init_info(group);
   if (ret < 0)
     {
-      goto errout_with_member;
+      return ret;
     }
 
 #ifndef CONFIG_DISABLE_PTHREAD
-  /* Initialize the pthread join mutex */
+  /* Initialize the task group join */
 
-  nxmutex_init(&group->tg_joinlock);
+  nxrmutex_init(&group->tg_joinlock);
+  sq_init(&group->tg_joinqueue);
 #endif
 
 #if defined(CONFIG_SCHED_WAITPID) && !defined(CONFIG_SCHED_HAVE_PARENT)
@@ -200,24 +174,17 @@ int group_allocate(FAR struct task_tcb_s *tcb, uint8_t ttype)
 #endif
 
   return OK;
-
-errout_with_member:
-#ifdef HAVE_GROUP_MEMBERS
-  kmm_free(group->tg_members);
-errout_with_group:
-#endif
-  kmm_free(group);
-  return ret;
 }
 
 /****************************************************************************
- * Name: group_initialize
+ * Name: group_postinitialize
  *
  * Description:
  *   Add the task as the initial member of the group.  The full creation of
  *   the group of a two step process:  (1) First, this group structure is
- *   allocated by group_allocate() early in the task creation sequence, then
- *   (2) this function  is called to set up the initial group membership.
+ *   allocated by group_initialize() early in the task creation sequence,
+ *   then (2) this function  is called to set up the initial group
+ *   membership.
  *
  * Input Parameters:
  *   tcb - The tcb in need of the task group.
@@ -231,12 +198,9 @@ errout_with_group:
  *
  ****************************************************************************/
 
-void group_initialize(FAR struct task_tcb_s *tcb)
+void group_postinitialize(FAR struct task_tcb_s *tcb)
 {
   FAR struct task_group_s *group;
-#if defined(HAVE_GROUP_MEMBERS)
-  irqstate_t flags;
-#endif
 
   DEBUGASSERT(tcb && tcb->cmn.group);
   group = tcb->cmn.group;
@@ -249,7 +213,7 @@ void group_initialize(FAR struct task_tcb_s *tcb)
 #ifdef HAVE_GROUP_MEMBERS
   /* Assign the PID of this new task as a member of the group. */
 
-  group->tg_members[0] = tcb->cmn.pid;
+  sq_addlast(&tcb->cmn.member, &group->tg_members);
 #endif
 
   /* Save the ID of the main task within the group of threads.  This needed
@@ -259,17 +223,4 @@ void group_initialize(FAR struct task_tcb_s *tcb)
    */
 
   group->tg_pid = tcb->cmn.pid;
-
-  /* Mark that there is one member in the group, the main task */
-
-  group->tg_nmembers = 1;
-
-#if defined(HAVE_GROUP_MEMBERS)
-  /* Add the initialized entry to the list of groups */
-
-  flags = enter_critical_section();
-  group->flink = g_grouphead;
-  g_grouphead = group;
-  leave_critical_section(flags);
-#endif
 }
