@@ -45,29 +45,6 @@
 #  define NUSER_IRQS NR_IRQS
 #endif
 
-/* INCR_COUNT - Increment the count of interrupts taken on this IRQ number */
-
-#ifndef CONFIG_SCHED_IRQMONITOR
-#  define INCR_COUNT(ndx)
-#elif defined(CONFIG_HAVE_LONG_LONG)
-#  define INCR_COUNT(ndx) \
-     do \
-       { \
-         g_irqvector[ndx].count++; \
-       } \
-     while (0)
-#else
-#  define INCR_COUNT(ndx) \
-     do \
-       { \
-         if (++g_irqvector[ndx].lscount == 0) \
-           { \
-             g_irqvector[ndx].mscount++; \
-           } \
-       } \
-     while (0)
-#endif
-
 /* CALL_VECTOR - Call the interrupt service routine attached to this
  * interrupt request
  */
@@ -80,14 +57,14 @@
 #  define CALL_VECTOR(ndx, vector, irq, context, arg) \
      do \
        { \
-         unsigned long start; \
-         unsigned long elapsed; \
-         start = up_perf_gettime(); \
+         clock_t start; \
+         clock_t elapsed; \
+         start = perf_gettime(); \
          vector(irq, context, arg); \
-         elapsed = up_perf_gettime() - start; \
+         elapsed = perf_gettime() - start; \
          if (ndx < NUSER_IRQS) \
            { \
-             INCR_COUNT(ndx); \
+             g_irqvector[ndx].count++; \
              if (elapsed > g_irqvector[ndx].time) \
                { \
                  g_irqvector[ndx].time = elapsed; \
@@ -96,8 +73,8 @@
          if (CONFIG_SCHED_CRITMONITOR_MAXTIME_IRQ > 0 && \
              elapsed > CONFIG_SCHED_CRITMONITOR_MAXTIME_IRQ) \
            { \
-             CRITMONITOR_PANIC("IRQ %d(%p), execute time too long %lu\n", \
-                               irq, vector, elapsed); \
+             CRITMONITOR_PANIC("IRQ %d(%p), execute time too long %ju\n", \
+                               irq, vector, (uintmax_t)elapsed); \
            } \
        } \
      while (0)
