@@ -29,7 +29,7 @@
 
 #include <signal.h>
 
-#ifdef CONFIG_PAGING
+#ifdef CONFIG_LEGACY_PAGING
 
 /****************************************************************************
  * Pre-processor Definitions
@@ -102,5 +102,5 @@ extern FAR struct tcb_s *g_pftcb;
 int pg_worker(int argc, FAR char *argv[]);
 
 #endif /* __ASSEMBLY__ */
-#endif /* CONFIG_PAGING */
+#endif /* CONFIG_LEGACY_PAGING */
 #endif /* __SCHED_PAGING_PAGING_H */
