@@ -82,14 +82,14 @@ bool nxsched_add_readytorun(FAR struct tcb_s *btcb)
        * g_pendingtasks task list for now.
        */
 
-      nxsched_add_prioritized(btcb, &g_pendingtasks);
+      nxsched_add_prioritized(btcb, list_pendingtasks());
       btcb->task_state = TSTATE_TASK_PENDING;
       ret = false;
     }
 
   /* Otherwise, add the new task to the ready-to-run task list */
 
-  else if (nxsched_add_prioritized(btcb, &g_readytorun))
+  else if (nxsched_add_prioritized(btcb, list_readytorun()))
     {
       /* The new btcb was added at the head of the ready-to-run list.  It
        * is now the new active task!
@@ -230,7 +230,7 @@ bool nxsched_add_readytorun(FAR struct tcb_s *btcb)
        * now.
        */
 
-      nxsched_add_prioritized(btcb, &g_pendingtasks);
+      nxsched_add_prioritized(btcb, list_pendingtasks());
       btcb->task_state = TSTATE_TASK_PENDING;
       doswitch         = false;
     }
@@ -244,7 +244,7 @@ bool nxsched_add_readytorun(FAR struct tcb_s *btcb)
        * Add the task to the ready-to-run (but not running) task list
        */
 
-      nxsched_add_prioritized(btcb, &g_readytorun);
+      nxsched_add_prioritized(btcb, list_readytorun());
 
       btcb->task_state = TSTATE_TASK_READYTORUN;
       doswitch         = false;
@@ -264,7 +264,7 @@ bool nxsched_add_readytorun(FAR struct tcb_s *btcb)
        * and check if a context switch will occur
        */
 
-      tasklist = &g_assignedtasks[cpu];
+      tasklist = list_assignedtasks(cpu);
       switched = nxsched_add_prioritized(btcb, tasklist);
 
       /* If the selected task list was the g_assignedtasks[] list and if the
@@ -338,12 +338,12 @@ bool nxsched_add_readytorun(FAR struct tcb_s *btcb)
               if (nxsched_islocked_global())
                 {
                   next->task_state = TSTATE_TASK_PENDING;
-                  tasklist         = &g_pendingtasks;
+                  tasklist         = list_pendingtasks();
                 }
               else
                 {
                   next->task_state = TSTATE_TASK_READYTORUN;
-                  tasklist         = &g_readytorun;
+                  tasklist         = list_readytorun();
                 }
 
               nxsched_add_prioritized(next, tasklist);
