@@ -138,7 +138,7 @@ int sched_unlock(void)
            */
 
           if (!nxsched_islocked_global() && !irq_cpu_locked(cpu) &&
-              g_pendingtasks.head != NULL)
+              list_pendingtasks()->head != NULL)
             {
               if (nxsched_merge_pending())
                 {
@@ -272,7 +272,7 @@ int sched_unlock(void)
            * fully independently.
            */
 
-          if (g_pendingtasks.head != NULL)
+          if (list_pendingtasks()->head != NULL)
             {
               if (nxsched_merge_pending())
                 {
