@@ -61,7 +61,7 @@
  * Input Parameters:
  *   pid - The task ID of the thread to waid for
  *   stat_loc - The location to return the exit status
- *   options - ignored
+ *   options - Modifiable behavior, see sys/wait.h.
  *
  * Returned Value:
  *   If nxsched_waitpid() returns because the status of a child process is
@@ -388,8 +388,11 @@ pid_t nxsched_waitpid(pid_t pid, int *stat_loc, int options)
 
               /* Discard the child entry and break out of the loop */
 
-              group_remove_child(rtcb->group, pid);
-              group_free_child(child);
+              if ((options & WNOWAIT) == 0)
+                {
+                  group_remove_child(rtcb->group, pid);
+                  group_free_child(child);
+                }
               break;
             }
         }
@@ -475,7 +478,7 @@ pid_t nxsched_waitpid(pid_t pid, int *stat_loc, int options)
 
               /* Discard the child entry, if we have one */
 
-              if (child != NULL)
+              if (child != NULL && (options & WNOWAIT) == 0)
                 {
                   group_remove_child(rtcb->group, child->ch_pid);
                   group_free_child(child);
@@ -591,7 +594,7 @@ errout:
  * Input Parameters:
  *   pid - The task ID of the thread to waid for
  *   stat_loc - The location to return the exit status
- *   options - ignored
+ *   options - Modifiable behavior, see sys/wait.h.
  *
  * Returned Value:
  *   If waitpid() returns because the status of a child process is available,
