@@ -99,18 +99,18 @@ static void nxsig_timeout(wdparm_t arg)
     {
       FAR struct tcb_s *rtcb = this_task();
 
-      wtcb->sigunbinfo.si_signo           = SIG_WAIT_TIMEOUT;
-      wtcb->sigunbinfo.si_code            = SI_TIMER;
-      wtcb->sigunbinfo.si_errno           = ETIMEDOUT;
-      wtcb->sigunbinfo.si_value.sival_int = 0;
+      wtcb->sigunbinfo->si_signo           = SIG_WAIT_TIMEOUT;
+      wtcb->sigunbinfo->si_code            = SI_TIMER;
+      wtcb->sigunbinfo->si_errno           = ETIMEDOUT;
+      wtcb->sigunbinfo->si_value.sival_int = 0;
 #ifdef CONFIG_SCHED_HAVE_PARENT
-      wtcb->sigunbinfo.si_pid             = 0;  /* Not applicable */
-      wtcb->sigunbinfo.si_status          = OK;
+      wtcb->sigunbinfo->si_pid             = 0;  /* Not applicable */
+      wtcb->sigunbinfo->si_status          = OK;
 #endif
 
       /* Remove the task from waitting list */
 
-      dq_rem((FAR dq_entry_t *)wtcb, &g_waitingforsignal);
+      dq_rem((FAR dq_entry_t *)wtcb, list_waitingforsignal());
 
       /* Add the task to ready-to-run task list, and
        * perform the context switch if one is needed
@@ -166,18 +166,18 @@ void nxsig_wait_irq(FAR struct tcb_s *wtcb, int errcode)
     {
       FAR struct tcb_s *rtcb = this_task();
 
-      wtcb->sigunbinfo.si_signo           = SIG_CANCEL_TIMEOUT;
-      wtcb->sigunbinfo.si_code            = SI_USER;
-      wtcb->sigunbinfo.si_errno           = errcode;
-      wtcb->sigunbinfo.si_value.sival_int = 0;
+      wtcb->sigunbinfo->si_signo           = SIG_CANCEL_TIMEOUT;
+      wtcb->sigunbinfo->si_code            = SI_USER;
+      wtcb->sigunbinfo->si_errno           = errcode;
+      wtcb->sigunbinfo->si_value.sival_int = 0;
 #ifdef CONFIG_SCHED_HAVE_PARENT
-      wtcb->sigunbinfo.si_pid             = 0;  /* Not applicable */
-      wtcb->sigunbinfo.si_status          = OK;
+      wtcb->sigunbinfo->si_pid             = 0;  /* Not applicable */
+      wtcb->sigunbinfo->si_status          = OK;
 #endif
 
       /* Remove the task from waitting list */
 
-      dq_rem((FAR dq_entry_t *)wtcb, &g_waitingforsignal);
+      dq_rem((FAR dq_entry_t *)wtcb, list_waitingforsignal());
 
       /* Add the task to ready-to-run task list, and
        * perform the context switch if one is needed
@@ -244,6 +244,7 @@ int nxsig_timedwait(FAR const sigset_t *set, FAR struct siginfo *info,
   irqstate_t flags;
   sclock_t waitticks;
   bool switch_needed;
+  siginfo_t sinfo;
   int ret;
 
   DEBUGASSERT(set != NULL);
@@ -311,6 +312,8 @@ int nxsig_timedwait(FAR const sigset_t *set, FAR struct siginfo *info,
         }
 #endif
 
+      rtcb->sigunbinfo = (info == NULL) ? &sinfo : info;
+
       /* Check if we should wait for the timeout */
 
       if (timeout != NULL)
@@ -358,7 +361,7 @@ int nxsig_timedwait(FAR const sigset_t *set, FAR struct siginfo *info,
               /* Add the task to the specified blocked task list */
 
               rtcb->task_state = TSTATE_WAIT_SIG;
-              dq_addlast((FAR dq_entry_t *)rtcb, &g_waitingforsignal);
+              dq_addlast((FAR dq_entry_t *)rtcb, list_waitingforsignal());
 
               /* Now, perform the context switch if one is needed */
 
@@ -400,7 +403,7 @@ int nxsig_timedwait(FAR const sigset_t *set, FAR struct siginfo *info,
           /* Add the task to the specified blocked task list */
 
           rtcb->task_state = TSTATE_WAIT_SIG;
-          dq_addlast((FAR dq_entry_t *)rtcb, &g_waitingforsignal);
+          dq_addlast((FAR dq_entry_t *)rtcb, list_waitingforsignal());
 
           /* Now, perform the context switch if one is needed */
 
@@ -418,26 +421,19 @@ int nxsig_timedwait(FAR const sigset_t *set, FAR struct siginfo *info,
        * or timeout) that awakened us.
        */
 
-      if (GOOD_SIGNO(rtcb->sigunbinfo.si_signo))
+      if (GOOD_SIGNO(rtcb->sigunbinfo->si_signo))
         {
           /* We were awakened by a signal... but is it one of the signals
            * that we were waiting for?
            */
 
-          if (nxsig_ismember(set, rtcb->sigunbinfo.si_signo))
+          if (nxsig_ismember(set, rtcb->sigunbinfo->si_signo))
             {
-              /* Return the signal info to the caller if so requested */
-
-              if (info != NULL)
-                {
-                  memcpy(info, &rtcb->sigunbinfo, sizeof(struct siginfo));
-                }
-
               /* Yes.. the return value is the number of the signal that
                * awakened us.
                */
 
-              ret = rtcb->sigunbinfo.si_signo;
+              ret = rtcb->sigunbinfo->si_signo;
             }
           else
             {
@@ -453,11 +449,11 @@ int nxsig_timedwait(FAR const sigset_t *set, FAR struct siginfo *info,
            */
 
 #ifdef CONFIG_CANCELLATION_POINTS
-          if (rtcb->sigunbinfo.si_signo == SIG_CANCEL_TIMEOUT)
+          if (rtcb->sigunbinfo->si_signo == SIG_CANCEL_TIMEOUT)
             {
               /* The wait was canceled */
 
-              ret = -rtcb->sigunbinfo.si_errno;
+              ret = -rtcb->sigunbinfo->si_errno;
               DEBUGASSERT(ret < 0);
             }
           else
@@ -467,11 +463,13 @@ int nxsig_timedwait(FAR const sigset_t *set, FAR struct siginfo *info,
                * error.
                */
 
-              DEBUGASSERT(rtcb->sigunbinfo.si_signo == SIG_WAIT_TIMEOUT);
+              DEBUGASSERT(rtcb->sigunbinfo->si_signo == SIG_WAIT_TIMEOUT);
               ret = -EAGAIN;
             }
         }
 
+      rtcb->sigunbinfo = NULL;
+
       leave_critical_section(flags);
     }
 
