@@ -167,8 +167,12 @@ if [ ! -r ${src_makedefs} ]; then
       src_makedefs=${configpath}/../../scripts/Make.defs
 
       if [ ! -r ${src_makedefs} ]; then
-        echo "File Make.defs could not be found"
-        exit 4
+        src_makedefs=${configpath}/../../../common/scripts/Make.defs
+
+        if [ ! -r ${src_makedefs} ]; then
+          echo "File Make.defs could not be found"
+          exit 4
+        fi
       fi
     fi
   fi
