@@ -67,7 +67,8 @@ enum compiler_e
   COMPILER_CLANG,
   COMPILER_MINGW,
   COMPILER_SDCC,
-  COMPILER_ZDSII
+  COMPILER_ZDSII,
+  COMPILER_TASKING
 };
 
 /****************************************************************************
@@ -200,6 +201,10 @@ static enum compiler_e get_compiler(char *ccname)
     {
       return COMPILER_ZDSII;
     }
+  else if (strstr(ccname, "ctc") != NULL)
+    {
+      return COMPILER_TASKING;
+    }
   else
     {
       /* Unknown compiler. Assume GCC-compatible */
@@ -347,7 +352,7 @@ int main(int argc, char **argv, char **envp)
       wintool = true;
 #endif
     }
-  else if (compiler == COMPILER_SDCC)
+  else if (compiler == COMPILER_SDCC || compiler == COMPILER_TASKING)
     {
       cmdarg = "-I";
     }
