@@ -81,12 +81,12 @@
  * Private Types
  ****************************************************************************/
 
-enum slashmode_e
+typedef enum
 {
-  MODE_FSLASH  = 0,
-  MODE_BSLASH  = 1,
-  MODE_DBLBACK = 2
-};
+  COMPILER_GNU      = 0,
+  COMPILER_TASKING  = 1,
+  COMPILER_NUM      = 2
+} compiler_t;
 
 /****************************************************************************
  * Private Data
@@ -115,10 +115,37 @@ static char g_posixpath[MAX_PATH];
 static char g_shquote[MAX_SHQUOTE];
 #endif
 
+static const char * const g_moptions[COMPILER_NUM][2] =
+{
+  /* GNU C/C++ Compiler */
+
+  {
+    " -M ",
+    " -MT "
+  },
+
+  /* Tasking C/C++ Compiler */
+
+  {
+    " -Em ",
+    " --pass-c=--make-target="
+  }
+};
+
 /****************************************************************************
  * Private Functions
  ****************************************************************************/
 
+static compiler_t get_compiler(char *ccname)
+{
+  if (strstr(ccname, "ctc") != NULL)
+    {
+      return COMPILER_TASKING;
+    }
+
+  return COMPILER_GNU;
+}
+
 /* MinGW does not seem to provide strtok_r */
 
 #ifndef HAVE_STRTOK_R
@@ -684,7 +711,7 @@ static const char *convert_path(const char *path)
 
 static void do_dependency(const char *file)
 {
-  static const char moption[] = " -M ";
+  const char * const * moption;
   struct stat buf;
   char *alloc;
   char *altpath;
@@ -705,6 +732,8 @@ static void do_dependency(const char *file)
   separator =  g_winnative ? '\\' : '/';
 #endif
 
+  moption = g_moptions[get_compiler(g_cc)];
+
   /* Copy the compiler into the command buffer */
 
   cmdlen = strlen(g_cc);
@@ -741,15 +770,15 @@ static void do_dependency(const char *file)
           *dotptr = '\0';
         }
 
-      snprintf(tmp, NAME_MAX + 6, " -MT %s%c%s%s ",
-               g_objpath, separator, objname, g_suffix);
+      snprintf(tmp, NAME_MAX + 6, "%s%s%c%s%s ",
+               moption[1], g_objpath, separator, objname, g_suffix);
       expanded = do_expand(tmp);
 
       cmdlen += strlen(expanded);
       if (cmdlen >= MAX_BUFFER)
         {
           fprintf(stderr, "ERROR: Option string is too long [%d/%d]: %s\n",
-                  cmdlen, MAX_BUFFER, moption);
+                  cmdlen, MAX_BUFFER, moption[0]);
           exit(EXIT_FAILURE);
         }
 
@@ -759,15 +788,15 @@ static void do_dependency(const char *file)
 
   /* Copy " -M " */
 
-  cmdlen += strlen(moption);
+  cmdlen += strlen(moption[0]);
   if (cmdlen >= MAX_BUFFER)
     {
       fprintf(stderr, "ERROR: Option string is too long [%d/%d]: %s\n",
-              cmdlen, MAX_BUFFER, moption);
+              cmdlen, MAX_BUFFER, moption[0]);
       exit(EXIT_FAILURE);
     }
 
-  strcat(g_command, moption);
+  strcat(g_command, moption[0]);
 
   /* Copy the CFLAGS into the command buffer */
 
